@@ -19,7 +19,11 @@ class DigitalSpi(DwfDevice_SubAPI):
     """
 
     def reset(self) -> None:
-        """Reset the SPI protocol support."""
+        """Reset the SPI protocol support.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the reset operation.
+        """
         result = self.lib.FDwfDigitalSpiReset(self.hdwf)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
@@ -29,6 +33,9 @@ class DigitalSpi(DwfDevice_SubAPI):
 
         Parameters:
             frequency (float): SPI frequency, in Hz.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
         """
         result = self.lib.FDwfDigitalSpiFrequencySet(self.hdwf, frequency)
         if result != RESULT_SUCCESS:
@@ -40,6 +47,9 @@ class DigitalSpi(DwfDevice_SubAPI):
         Parameters:
             channel_index (int):
                 Digital channel (pin) for the clock signal.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
         """
         result = self.lib.FDwfDigitalSpiClockSet(self.hdwf, channel_index)
         if result != RESULT_SUCCESS:
@@ -59,6 +69,9 @@ class DigitalSpi(DwfDevice_SubAPI):
 
             channel_index (int):
                 Digital channel (pin) for this data bit.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
         """
         result = self.lib.FDwfDigitalSpiDataSet(self.hdwf, spi_data_bit, channel_index)
         if result != RESULT_SUCCESS:
@@ -78,6 +91,9 @@ class DigitalSpi(DwfDevice_SubAPI):
 
             idle_mode (DwfDigitalOutIdle):
                 Idle behavior of this bit.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
         """
 
         result = self.lib.FDwfDigitalSpiIdleSet(self.hdwf, spi_data_bit, idle_mode.value)
@@ -94,6 +110,9 @@ class DigitalSpi(DwfDevice_SubAPI):
                 * 1: CPOL = 0, CPHA = 1
                 * 2: CPOL = 1, CPHA = 0
                 * 3: CPOL = 1, CPHA = 1
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
         """
         result = self.lib.FDwfDigitalSpiModeSet(self.hdwf, spi_mode)
         if result != RESULT_SUCCESS:
@@ -107,6 +126,9 @@ class DigitalSpi(DwfDevice_SubAPI):
 
                 * 1: MSB first, LSB last
                 * 0: LSB first, MSB last
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
         """
         result = self.lib.FDwfDigitalSpiOrderSet(self.hdwf, bit_order)
         if result != RESULT_SUCCESS:
@@ -122,6 +144,9 @@ class DigitalSpi(DwfDevice_SubAPI):
                 *  0: low
                 *  1: high
                 * -1: Z (high impedance)
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
         """
         result = self.lib.FDwfDigitalSpiSelect(self.hdwf, channel_index, level)
         if result != RESULT_SUCCESS:
@@ -140,8 +165,12 @@ class DigitalSpi(DwfDevice_SubAPI):
                 The number of bits per data-word (1..8).
             tx (List[int]):
                 The data-words to write.
+
         Returns:
             List[int]: The data-words received.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
         """
         tx_list = list(tx)
 
@@ -180,8 +209,12 @@ class DigitalSpi(DwfDevice_SubAPI):
                 The number of bits per data-word (1..16).
             tx (List[int]):
                 The data-words to write.
+
         Returns:
             List[int]: The data-words received.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
         """
         tx_list = list(tx)
 
@@ -220,8 +253,12 @@ class DigitalSpi(DwfDevice_SubAPI):
                 The number of bits per data-word (1..32).
             tx (List[int]):
                 The data-words to write.
+
         Returns:
             List[int]: The data-words received.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
         """
 
         tx_list = list(tx)
@@ -261,8 +298,12 @@ class DigitalSpi(DwfDevice_SubAPI):
                 The number of bits per data-word (1..8).
             number_of_words (int):
                 The number of data-words to read.
+
         Returns:
             List[int]: The data-words received.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
         """
 
         buffer_type = typespec_ctypes.c_unsigned_char * number_of_words
@@ -293,8 +334,12 @@ class DigitalSpi(DwfDevice_SubAPI):
                 * 4: quad
             bits_per_word (int):
                 The number of bits of the data-word (1..32).
+
         Returns:
             int: The data-word received.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
         """
         c_rx = typespec_ctypes.c_unsigned_int()
         result = self.lib.FDwfDigitalSpiReadOne(self.hdwf, transfer_type, bits_per_word, c_rx)
@@ -316,8 +361,12 @@ class DigitalSpi(DwfDevice_SubAPI):
                 The number of bits per data-word (1..16).
             number_of_words (int):
                 The number of data-words to read.
+
         Returns:
             List[int]: The data-words received.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
         """
 
         buffer_type = typespec_ctypes.c_unsigned_short * number_of_words
@@ -350,8 +399,12 @@ class DigitalSpi(DwfDevice_SubAPI):
                 The number of bits per data-word (1..32).
             number_of_words (int):
                 The number of data-words to read.
+
         Returns:
             List[int]: The data-words received.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
         """
 
         buffer_type = typespec_ctypes.c_unsigned_int * number_of_words
@@ -384,6 +437,9 @@ class DigitalSpi(DwfDevice_SubAPI):
                 The number of bits per data-word (1..32).
             tx (List[int]):
                 The data-words to write.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
         """
         tx_list = list(tx)
 
@@ -415,6 +471,9 @@ class DigitalSpi(DwfDevice_SubAPI):
                 The number of bits of the data-word (1..32).
             tx (int):
                 The data-word to write.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
         """
         result = self.lib.FDwfDigitalSpiWriteOne(self.hdwf, transfer_type, bits_per_word, tx)
         if result != RESULT_SUCCESS:
@@ -433,6 +492,9 @@ class DigitalSpi(DwfDevice_SubAPI):
                 The number of bits per data-word (1..16).
             tx (List[int]):
                 The data-words to write.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
         """
         tx_list = list(tx)
 
@@ -464,6 +526,9 @@ class DigitalSpi(DwfDevice_SubAPI):
                 The number of bits per data-word (1..32).
             tx (List[int]):
                 The data-words to write.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
         """
         tx_list = list(tx)
 
